﻿using System;
using System.Diagnostics;
using System.ComponentModel;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Collections.ObjectModel;
using System.Data;
using System.Data.Common;
using System.Globalization;
using System.Reflection;
using System.Text;
using System.Transactions;
using System.Xml;
using System.Web;
using System.Net;
using System.IO;
using System.Threading;
using Produmex.Foundation;
using Produmex.Foundation.Barcode;
using Produmex.Foundation.Data;
using Produmex.Foundation.Data.DataSetClient;
using Produmex.Foundation.Data.DbClient;
using Produmex.Foundation.Data.Sbo;
using Produmex.Foundation.Data.Sbo.BusinessObjects;
using Produmex.Foundation.Data.Sbo.BusinessObjects.Definitions.Tables;      
using Produmex.Foundation.Data.Sbo.DataObjects;
using Produmex.Foundation.Data.Sbo.Generators.BarcodeController;
using Produmex.Foundation.Data.Sbo.Providers;
using Produmex.Foundation.Data.Sbo.Utilities;
using Produmex.Foundation.Data.SqlClient;
using Produmex.Foundation.Diagnostics;
using Produmex.Foundation.Messages;
using Produmex.Foundation.SlimScreen;
using Produmex.Foundation.SlimScreen.Interfaces.Definitions;
using Produmex.Foundation.SlimScreen.Interfaces.Definitions.KnownDataSets;
using Produmex.Foundation.SlimScreen.WinGui;
using Produmex.Foundation.Utilities;
using Produmex.Foundation.Workflows;
using Produmex.Foundation.Workflows.Parameters;
using Produmex.Foundation.Wwf.Sbo.DataObjects;
using Produmex.Foundation.Wwf.Sbo.LocalServices;
using Produmex.Sbo.Logex.Data.BusinessObjects;
using Produmex.Sbo.Logex.Data.BusinessObjects.Definitions;
using Produmex.Sbo.Logex.Data.BusinessObjects.Definitions.Tables;
using Produmex.Sbo.Logex.Data.DataObjects;
using Produmex.Sbo.Logex.Data.Generators.PackingController;
using Produmex.Sbo.Logex.Data.Providers;
using Produmex.Sbo.Logex.Data.ViewObjects.Definitions.Views;
using Produmex.Sbo.Logex.Suma.BusinessObjects.Definitions.Tables;



// PmxWorkflowExecutionTypes.SUB_FLOW
namespace Produmex.Sbo.Logex.WorkflowScripts
{
	/// <summary>
	/// Pre Receipt Suma
	/// </summary>
	public class WorkflowScript_PreReceiptSumaScript : WorkflowInstanceScriptBase
	{
        private static class Definitions
        {
            public const string REPORT_LABEL = @"SumaReceiptLabel.rpt";

        }

		// Input parameters
		public ReadOnlyBinder<CultureInfo>   DefaultCultureInfo;
		public ReadOnlyBinder<PmxOseCompany> PmxOseCompany;

		private static readonly ILog s_log = LogProvider.GetLogger(MethodInfo.GetCurrentMethod().DeclaringType);




		/// <summary>
		/// The m_enter quality values flow
		/// </summary>
		private WorkflowInstanceBase m_enterQualityValuesFlow;

		/// <summary>
		/// The m_enter quality values flow_ list of quality values
		/// </summary>
		protected Collection<QualityValueInfo> m_enterQualityValuesFlow_ListOfQualityValues;

		protected bool m_subFlowBackRequested;


		#region Constructors

		public WorkflowScript_PreReceiptSumaScript(WorkflowInstanceBase parent, WorkflowInstanceFactory factory)
			: base(parent, factory)
		{

			m_enterQualityValuesFlow = this.Create("EnterQualityValuesScript");

		}

		#endregion

		#region WorkflowInstanceScriptBase Members

		/// <summary>
		/// Executes this instance.
		/// </summary>
		protected override void Execute()
		{
			// Parameters in scope
			Session session = GetScopeParameter("Session") as Session;
			ISboProviderService sboProviderService = GetScopeParameter("<WwfService>ISboService") as ISboProviderService;
			ProdumexError pmxError = null;

			string initialErrorKey = null;
			string deviceID = session.DeviceInstanceId;
			SboUserInfo userInfo = sboProviderService.GetCurrentUser();
			string query = null;



			Message msg = null;
			int? purchaseOrderDocEntry = null;
			DataSet dsPurchaseOrders = null;
			DocumentRef purchaseDocRef = null;
			int? purchaseOrderDocNum = null;

			int numberOfCopies = 1;

		Step_SelectOrder:

			#region SELECT ORDER


			purchaseDocRef = null;
			purchaseOrderDocEntry = null;
			purchaseOrderDocNum = null;
			query = BuildQuery.GetPOsOrderByPONumber(sboProviderService.GetDbTool());  // Don't show reserve invoices when cross-docking
			dsPurchaseOrders = sboProviderService.RunView(false, null, null, query);


			session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.Reception.ISelectPOScreen),
				DefaultCultureInfo.Get(), BuildParamCollection(
				"InitialErrorKey", initialErrorKey,
				"TitleKey", "MSG_TITLE_SELECT_PO",
				"ButtonKey", "",
				"PODS", dsPurchaseOrders
				));

			msg = WaitForMessage();
			initialErrorKey = null;
			if (msg.Name.EndsWith(".POSelected"))
			{
				purchaseDocRef = new DocumentRef(ExtractParameter<string>(msg.Parameters, "docObjType"), ExtractParameter<int>(msg.Parameters, "docEntry"));

				DataRow[] rows = dsPurchaseOrders.Tables[0].Select(PurchaseOrderDataSet.Columns.DOC_OBJ_TYPE.Name + " = " + purchaseDocRef.DocType
					+ " AND " + PurchaseOrderDataSet.Columns.PO_ID.Name + " = " + purchaseDocRef.DocEntry.ToString());

				if (rows.Length > 0)
				{
					purchaseOrderDocNum = Convertor.ConvertToInt32Nullable(rows[0][PurchaseOrderDataSet.Columns.PO_NUMBER.Name]);
				}

				goto Step_AskQualityValues;
			}

			if (msg.Name.EndsWith("ISelectPOScreenReply.RefreshRequested"))
			{
				goto Step_SelectOrder;
			}

			if (msg.Name.EndsWith(".ButtonClicked"))
			{
				//Not supported
				goto Step_SelectOrder;
			}

			//Go back
			return;

			#endregion

		Step_AskQualityValues:

			#region ASK QUALITY VALUES

			m_enterQualityValuesFlow.BindParameters(
			 this.DefaultCultureInfo,
			 this.PmxOseCompany,
			 new ReadOnlyBinder<PmxMomentOfCapture>("MomentOfCapture", PmxMomentOfCapture.Start),
			 new ReadOnlyBinder<string>("BaseType", "SUMA_22"),
			 new ReadOnlyBinder<int?>("BaseEntry", purchaseDocRef.DocEntry),
			 new ReadOnlyBinder<bool>("OnlyAskWhenNotRegisteredYet", false),
			 new ReadOnlyBinder<bool>("SaveData", true),

			 new ReadWriteBinder<bool>("BackRequested", this, "m_subFlowBackRequested"),
			 new ReadWriteBinder<Collection<QualityValueInfo>>("ListOfQualityValues", this, "m_enterQualityValuesFlow_ListOfQualityValues")

			 );

			m_subFlowBackRequested = false;
			this.StartSubFlowAndWait(m_enterQualityValuesFlow, true);

			if (m_subFlowBackRequested)
			{
				goto Step_SelectOrder;
			}


			goto Step_AskRejectOrAccept;

			#endregion

		Step_AskRejectOrAccept:

			#region ASK REJECT OR ACCEPT

			session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IDecisionScreen),
					DefaultCultureInfo.Get(), BuildParamCollection(
						"TitleKey", "MSG_TITLE_PRERECEIPT_ACCEPT_OR_REJECT_ORDER",
						"MessageKey", "MSG_QUESTION_PRERECEIPT_ACCEPT_OR_REJECT_ORDER",
						"AllowToGoBack", true,
						"ButtonKeyYes", "MSG_BUTTON_ACCEPT",
						"ButtonKeyNo", "MSG_BUTTON_REJECT"));
			msg = WaitForMessage();

			if (msg.Name.EndsWith(".Yes"))
			{
				goto Step_AskNumberOfCopies;
			}
			else if (msg.Name.EndsWith(".No"))
			{
				//The 'Approved' field should be set to False (OPOR.Confirmed = N)
				query = BuildQuery.SetConfirmedToN((int)purchaseOrderDocNum);
				sboProviderService.RunView(false, null, null, query);
				goto Step_SelectOrder;
			}
			else
			{
				//Go back
				goto Step_SelectOrder;
			}

			#endregion

		Step_AskNumberOfCopies:

			#region ASK NUMBER OF COPIES

			numberOfCopies = 1;


			//ask user for number of labels
			session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IEnterQuantityScreen),
				DefaultCultureInfo.Get(), BuildParamCollection(
					"InitialErrorKey", initialErrorKey,
					"TitleKey", "MSG_TITLE_ENTER_QUANTITY_TO_PRINT",
					"InitialQuantity", 1,
					"NumberOfDigitsAfterDecimal", 0,
					"MaximumQuantity", -1,
					"SetFocusToQuantityControl", true
				   ));
			msg = WaitForMessage();

			//clear data
			initialErrorKey = null;

			if (msg.Name.EndsWith(".QuantityEntered"))
			{
				numberOfCopies = Convert.ToInt32(ExtractParameter<double>(msg.Parameters, "quantity"));

				goto Step_AdjustSupplierReference;
			}
			else if (msg.Name.EndsWith(".BackRequested"))
			{
				goto Step_SelectOrder;
			}
			#endregion

		Step_AdjustSupplierReference:

			#region ADJUST SUPPLIER REFERENCE


			try
			{
				query = BuildQuery.SetNumberOfCopies((int)purchaseOrderDocNum, numberOfCopies);
				sboProviderService.RunView(false, null, null, query);

				sboProviderService.InvokeMethodWithDbConnection<object>(true, false, null, null,
				delegate(PmxDbConnection conn, object[] parameters)
				{
					PmxPurchaseOrderProvider poProv = new PmxPurchaseOrderProvider((SboConnection)conn);

					using (PmxPurchaseOrder po = poProv.GetBO(purchaseDocRef.DocEntry))
					{
						if (po != null)
						{
							po.NumAtCard = string.Format("{0}{1}", po.DocNumber, DateTime.Now.ToString("yyyyMMdd"));

							poProv.UpdateBO(po, false, false);
						}
					}


					return null;
				});

			}
			catch (Exception ex)
			{
				//Ask if 
				s_log.Error("", ex);
				if (!(ex is ProdumexException) || ((ProdumexException)ex).Error == null)
				{
					// Inform the user with the error
					session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IShowMessageScreen),
						DefaultCultureInfo.Get(), BuildParamCollection(
							"MessageKey", ExceptionHelper.Format(ex, this.DefaultCultureInfo),
							"NoTranslationOfMessageKey", true,
							"IsError", true,
							"ShowButton", true));
					WaitForMessage();

				}
				else
				{
					// Inform the user with the error
					session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IShowMessageScreen),
						DefaultCultureInfo.Get(), BuildParamCollection(
							"PmxError", ((ProdumexException)ex).Error,
							"ShowButton", true));
					WaitForMessage();
				}

				//retry?
				//ask user if he wants to retry
				session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IDecisionScreen),
					DefaultCultureInfo.Get(), BuildParamCollection(
						"TitleKey", "MSG_TITLE_RETRY_UPDATE",
						"MessageKey", "MSG_QUESTION_AN_ERROR_OCCURED_WANT_RETRY"));
				msg = WaitForMessage();

				if (msg.Name.ToLower().EndsWith(".yes"))
				{
					goto Step_AdjustSupplierReference;
				}

			}

			goto Step_PrintLabels;


			#endregion

		Step_PrintLabels:

			#region PRINT REPORT

			try
			{
				//print report
				sboProviderService.InvokeMethodWithDbConnection<PmxOsePrinter>(false, false, null, null, new DelegateWithPmxDbConnection<PmxOsePrinter>(ExecutePrintLabelReport), purchaseDocRef.DocEntry, session.DeviceInstanceId, Definitions.REPORT_LABEL, null, numberOfCopies);

				Thread.Sleep(750);

			}
			catch (Exception ex)
			{
				//Ask if 
				s_log.Error("", ex);
				if (!(ex is ProdumexException) || ((ProdumexException)ex).Error == null)
				{
					// Inform the user with the error
					session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IShowMessageScreen),
						DefaultCultureInfo.Get(), BuildParamCollection(
							"MessageKey", ExceptionHelper.Format(ex, this.DefaultCultureInfo),
							"NoTranslationOfMessageKey", true,
							"IsError", true,
							"ShowButton", true));
					WaitForMessage();

				}
				else
				{
					// Inform the user with the error
					session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IShowMessageScreen),
						DefaultCultureInfo.Get(), BuildParamCollection(
							"PmxError", ((ProdumexException)ex).Error,
							"ShowButton", true));
					WaitForMessage();
				}

				//retry?
				//ask user if he wants to retry
				session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IDecisionScreen),
					DefaultCultureInfo.Get(), BuildParamCollection(
						"TitleKey", "MSG_TITLE_RETRY_UPDATE",
						"MessageKey", "MSG_QUESTION_AN_ERROR_OCCURED_WANT_RETRY"));
				msg = WaitForMessage();

				if (msg.Name.ToLower().EndsWith(".yes"))
				{
					goto Step_PrintLabels;
				}
			}

			// Inform the user
			session.ShowScreen(typeof(Produmex.Foundation.SlimScreen.Interfaces.IShowMessageScreen),
				DefaultCultureInfo.Get(), BuildParamCollection(
					"MessageKey", "MSG_LABELS_PRINTED",
					"NoTranslationOfMessageKey", false,
					"IsError", false,
					"ShowButton", true));
			WaitForMessage();

			goto Step_SelectOrder;

			#endregion

		


		}

		#endregion



		#region HELPERS

		/// <summary>
		/// Executes the get PMX warehouse info.
		/// </summary>
		/// <param name="conn">The conn.</param>
		/// <param name="parameters">The parameters.</param>
		/// <returns></returns>
		private static PmxOseWarehouseInfo ExecuteGetPmxWarehouseInfo(PmxDbConnection conn, object[] parameters)
		{
			PmxOseProvider oseProv = new PmxOseProvider(conn);
			return oseProv.GetPmxWarehouseInfo((string)parameters[0]);
		}

		/// <summary>
		/// Gets the number of rows.
		/// </summary>
		/// <param name="ds">The ds.</param>
		/// <returns></returns>
		private int GetNumberOfRows(DataSet ds)
		{
			if (ds != null &&
				ds.Tables.Count > 0)
			{
				return ds.Tables[0].Rows.Count;
			}

			return 0;
		}

		/// <summary>
		/// Executes the get item info.
		/// </summary>
		/// <param name="conn">The conn.</param>
		/// <param name="parameters">The parameters.</param>
		/// <returns></returns>
		private static PmxItemInfo ExecuteGetItemInfo(PmxDbConnection conn, object[] parameters)
		{
			PmxItemAllConnectionsProvider prov = new PmxItemAllConnectionsProvider(conn);
			return prov.GetCachedItemInfo((string)parameters[0]);
		}

        /// <summary>
        /// Executes the report.
        /// </summary>
        /// <param name="conn">The conn.</param>
        /// <param name="parameters">The parameters.</param>
        /// <returns></returns>
        private static PmxOsePrinter ExecutePrintLabelReport(PmxDbConnection conn, object[] parameters)
        {
            PmxPrintReportProvider prov = new PmxPrintReportProvider(conn);

            Collection<ReportParameter> reportParameters = new Collection<ReportParameter>();
            reportParameters.Add(new ReportParameter("@docEntry", (int)parameters[0]));

			return prov.PrintReport(reportParameters, (string)parameters[2], (int)parameters[4], (string)parameters[1], (string)parameters[3], false);
        }

 
        #endregion
    }

	#region BUILD QUERY

	/// <summary>
	/// Static class grouping our native queries
	/// </summary>
	internal static class BuildQuery
	{

		/// <summary>
		/// Command for getting all PO's order by PO Number
		/// </summary>
		/// <param name="dbTool">The db tool.</param>
		/// <returns>
		/// Command for getting all PO's order by PO Number
		/// </returns>
		public static string GetPOsOrderByPONumber(DbTool dbTool)
		{
			DbQueryBuilder strBuilder = dbTool.GetQueryBuilder();
			strBuilder.AppendFormat("SELECT DISTINCT {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.ObjType.NAME, PurchaseOrderDataSet.Columns.DOC_OBJ_TYPE.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.DocNum.NAME, PurchaseOrderDataSet.Columns.PO_NUMBER.Name));
			strBuilder.AppendFormat(", CAST( {0} AS NVARCHAR ) AS {1}",
				SqlCommandHelper.EscapeTableColumnName(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.DocNum.NAME),
				SqlCommandHelper.EscapeColumnName(PurchaseOrderDataSet.Columns.PO_NUMBER_ASSTRING.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.DocEntry.NAME, PurchaseOrderDataSet.Columns.PO_ID.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.CardCode.NAME, PurchaseOrderDataSet.Columns.SUPPLIER_CODE.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.CardName.NAME, PurchaseOrderDataSet.Columns.SUPPLIER_NAME.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.NumAtCard.NAME, PurchaseOrderDataSet.Columns.SUPPLIER_REFERENCE.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeTableColumnNameWithAlias(PmxPurchaseOrderLineTable.NAME, PmxPurchaseOrderLineTable.Columns.SupplierLineRef.NAME, PurchaseOrderDataSet.Columns.SUPPLIER_LINE_REF.Name));

			strBuilder.AppendFormat("\r\n FROM {0}",
				SqlCommandHelper.EscapeTableName(SboPurchaseOrderTable.NAME));

			strBuilder.AppendFormat("\r\n INNER JOIN {0}",
				SqlCommandHelper.EscapeTableName(PmxPurchaseOrderLineTable.NAME));
			strBuilder.AppendFormat(" ON {0} = {1}",
				SqlCommandHelper.EscapeTableColumnName(PmxPurchaseOrderLineTable.NAME, PmxPurchaseOrderLineTable.Columns.DocEntry.NAME),
				SqlCommandHelper.EscapeTableColumnName(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.DocEntry.NAME));

			strBuilder.AppendFormat("\r\n INNER JOIN {0}",
				SqlCommandHelper.EscapeTableName(SboItemTable.NAME));
			strBuilder.AppendFormat(" ON {0} = {1}",
				SqlCommandHelper.EscapeTableColumnName(SboItemTable.NAME, SboItemTable.Columns.ItemCode.NAME),
				SqlCommandHelper.EscapeTableColumnName(PmxPurchaseOrderLineTable.NAME, PmxPurchaseOrderLineTable.Columns.ItemCode.NAME));

		

			strBuilder.AppendFormat("\r\n WHERE {0} = {1}",
				SqlCommandHelper.EscapeTableColumnName(SboPurchaseOrderTable.NAME, SboPurchaseOrderTable.Columns.DocStatus.NAME),
				SqlCommandHelper.FormatAndEscapeColumnValue(SboDocStatusColumnValues.Open.VALUE, CultureInfo.InvariantCulture));

			strBuilder.Append(" AND ");
			strBuilder.Append(SqlCommandHelper.EscapeTableName(SboPurchaseOrderTable.NAME));
			strBuilder.Append(".");
			strBuilder.Append(SqlCommandHelper.EscapeColumnName(SboPurchaseOrderTable.Columns.Canceled.NAME));
			strBuilder.Append(" = ");
			strBuilder.Append(SqlCommandHelper.FormatAndEscapeColumnValue(SboBooleanColumnValues.N.VALUE, CultureInfo.InvariantCulture));

			strBuilder.Append(" AND ");
			strBuilder.Append(SqlCommandHelper.EscapeTableName(SboPurchaseOrderTable.NAME));
			strBuilder.Append(".");
			strBuilder.Append(SqlCommandHelper.EscapeColumnName(SboPurchaseOrderTable.Columns.Confirmed.NAME));
			strBuilder.Append(" = ");
			strBuilder.Append(SqlCommandHelper.FormatAndEscapeColumnValue(SboBooleanColumnValues.Y.VALUE, CultureInfo.InvariantCulture));

			strBuilder.Append(" AND ");
			strBuilder.Append(SqlCommandHelper.EscapeTableName(SboPurchaseOrderLineTable.NAME));
			strBuilder.Append(".");
			strBuilder.Append(SqlCommandHelper.EscapeColumnName(SboPurchaseOrderLineTable.Columns.LineStatus.NAME));
			strBuilder.Append(" = ");
			strBuilder.Append(SqlCommandHelper.FormatAndEscapeColumnValue(SboDocStatusColumnValues.Open.VALUE, CultureInfo.InvariantCulture));

			strBuilder.Append(" AND ");
			strBuilder.Append(SqlCommandHelper.EscapeTableName(PmxItemTable.NAME));
			strBuilder.Append(".");
			strBuilder.Append(SqlCommandHelper.EscapeColumnName(PmxItemTable.Columns.InventoryItem.NAME));
			strBuilder.Append(" = ");
			strBuilder.Append(SqlCommandHelper.FormatAndEscapeColumnValue(SboBooleanColumnValues.Y.VALUE, CultureInfo.InvariantCulture));

			
			strBuilder.AppendFormat("\r\n ORDER BY {0}",
				SqlCommandHelper.EscapeColumnName(PurchaseOrderDataSet.Columns.DOC_OBJ_TYPE.Name));
			strBuilder.AppendFormat(", {0}",
				SqlCommandHelper.EscapeColumnName(PurchaseOrderDataSet.Columns.PO_NUMBER.Name));

			return strBuilder.ToString();
		}

		/// <summary>
		/// Set confirmed to no
		/// </summary>
		/// <param name="docNum">Document number</param>
		/// <returns>Query</returns>
		public static string SetConfirmedToN(int docNum)
		{
			StringBuilder strBuilder = new StringBuilder();
			strBuilder.AppendFormat("UPDATE {0} SET {1} = '{2}' WHERE {3} = {4}",
				SqlCommandHelper.EscapeTableName(SboPurchaseOrderTable.NAME),
				SqlCommandHelper.EscapeColumnName(SboPurchaseOrderTable.Columns.Confirmed.NAME),
				SqlCommandHelper.EscapeColumnValue("N"),
				SqlCommandHelper.EscapeColumnName(SboPurchaseOrderTable.Columns.DocNum.NAME),
				SqlCommandHelper.EscapeColumnValue(docNum));

			return strBuilder.ToString();
		}

		/// <summary>
		/// Set number of copies
		/// </summary>
		/// <param name="docNum">Document number</param>
		/// <param name="numberOfCopies">Number of copies</param>
		/// <returns>Query</returns>
		public static string SetNumberOfCopies(int docNum, int numberOfCopies)
		{
			StringBuilder strBuilder = new StringBuilder();
			strBuilder.AppendFormat("UPDATE {0} SET {1} = {2} WHERE {3} = {4}",
				SqlCommandHelper.EscapeTableName(SboPurchaseOrderTable.NAME),
				SqlCommandHelper.EscapeColumnName(SboPurchaseOrderSUMATable.Columns.NumberOfEnteredLabels.NAME),
				SqlCommandHelper.EscapeColumnValue(numberOfCopies),
				SqlCommandHelper.EscapeColumnName(SboPurchaseOrderTable.Columns.DocNum.NAME),
				SqlCommandHelper.EscapeColumnValue(docNum));

			return strBuilder.ToString();
		}
	}


	#endregion

}
